"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.getSerializer = exports.addSerializer = exports.serializer = void 0;
const serializeArrayBuffer_js_1 = require("./serializeArrayBuffer.js");
const serializeBuffer_js_1 = require("./serializeBuffer.js");
const serializeDate_js_1 = require("./serializeDate.js");
const serializeError_js_1 = require("./serializeError.js");
const serializeHeaders_js_1 = require("./serializeHeaders.js");
const serializeMap_js_1 = require("./serializeMap.js");
const serializeSet_js_1 = require("./serializeSet.js");
const serializeURLSearchParams_js_1 = require("./serializeURLSearchParams.js");
const serializeUrl_js_1 = require("./serializeUrl.js");
exports.serializer = new Map();
/**
 * Add a new Serializer
 */
const addSerializer = (name, fn) => exports.serializer.set(name, fn);
exports.addSerializer = addSerializer;
/**
 * Get a Serializer by constructor name
 */
const getSerializer = (name) => exports.serializer.get(name);
exports.getSerializer = getSerializer;
(0, exports.addSerializer)('Buffer', serializeBuffer_js_1.serializeBuffer);
(0, exports.addSerializer)('ArrayBuffer', serializeArrayBuffer_js_1.serializeArrayBuffer);
(0, exports.addSerializer)('Map', serializeMap_js_1.serializeMap);
(0, exports.addSerializer)('Set', serializeSet_js_1.serializeSet);
(0, exports.addSerializer)('Date', serializeDate_js_1.serializeDate);
(0, exports.addSerializer)('Headers', serializeHeaders_js_1.serializeHeaders);
(0, exports.addSerializer)('URL', serializeUrl_js_1.serializeUrl);
(0, exports.addSerializer)('URLSearchParams', serializeURLSearchParams_js_1.serializeURLSearchParams);
// Errors
(0, exports.addSerializer)('AssertionError', serializeError_js_1.serializeError);
(0, exports.addSerializer)('Error', serializeError_js_1.serializeError);
(0, exports.addSerializer)('EvalError', serializeError_js_1.serializeError);
(0, exports.addSerializer)('RangeError', serializeError_js_1.serializeError);
(0, exports.addSerializer)('ReferenceError', serializeError_js_1.serializeError);
(0, exports.addSerializer)('SyntaxError', serializeError_js_1.serializeError);
(0, exports.addSerializer)('SystemError', serializeError_js_1.serializeError);
(0, exports.addSerializer)('TypeError', serializeError_js_1.serializeError);
(0, exports.addSerializer)('URIError', serializeError_js_1.serializeError);
