declare const _default: "\n\nclass TextEncoder {\n    encode(input = '') {\n        const utf8 = unescape(encodeURIComponent(input));\n        const result = new Uint8Array(utf8.length);\n        \n        for (let i = 0; i < utf8.length; i++) {\n            result[i] = utf8.charCodeAt(i);\n        }\n          \n        return result;\n    }\n}\n\nclass TextDecoder {\n    constructor(encoding = 'utf-8') {\n        if (encoding !== 'utf-8') {\n            throw new Error('Only utf-8 encoding is supported');\n        }\n    }\n\n    decode(input = new Uint8Array()) {\n        let str = '';\n        for (let i = 0; i < input.length; i++) {\n          str += String.fromCharCode(input[i]);\n        }\n        return decodeURIComponent(escape(str));\n    }\n}\n\n// Promisify: converts a callback-based function to a promise-based one\nfunction promisify(fn) {\n  return function (...args) {\n    return new Promise((resolve, reject) => {\n      fn(...args, (err, result) => {\n        if (err) {\n          reject(err);\n        } else {\n          resolve(result);\n        }\n      });\n    });\n  };\n}\n\n// Callbackify: converts a promise-based function to a callback-based one\nfunction callbackify(fn) {\n  return function (...args) {\n    const cb = args.pop();\n    fn(...args)\n      .then((result) => cb(null, result))\n      .catch((err) => cb(err));\n  };\n}\n\n// Inherits: implements inheritance\nfunction inherits(ctor, superCtor) {\n  if (typeof superCtor !== 'function' && superCtor !== null) {\n    throw new TypeError('Super constructor must either be a function or null');\n  }\n\n  ctor.super_ = superCtor;\n  if (Object.setPrototypeOf) {\n    Object.setPrototypeOf(ctor.prototype, superCtor.prototype);\n  } else {\n    ctor.prototype.__proto__ = superCtor.prototype;\n  }\n}\n\n// Deprecate: marks a method as deprecated\nfunction deprecate(fn, msg) {\n  let warned = false;\n  function deprecated(...args) {\n    if (!warned) {\n      console.warn(`DeprecationWarning: ${msg}`);\n      warned = true;\n    }\n    return fn.apply(this, args);\n  }\n  return deprecated;\n}\n\nconst types = {\n    isAnyArrayBuffer(value) {\n      return value instanceof ArrayBuffer || value instanceof SharedArrayBuffer;\n    },\n    isArrayBufferView(value) {\n      return ArrayBuffer.isView(value);\n    },\n    isArgumentsObject(value) {\n      return Object.prototype.toString.call(value) === '[object Arguments]';\n    },\n    isArrayBuffer(value) {\n      return value instanceof ArrayBuffer;\n    },\n    isAsyncFunction(value) {\n      return Object.prototype.toString.call(value) === '[object AsyncFunction]';\n    },\n    isBigInt64Array(value) {\n      return value instanceof BigInt64Array;\n    },\n    isBigUint64Array(value) {\n      return value instanceof BigUint64Array;\n    },\n    isBooleanObject(value) {\n      return typeof value === 'object' && typeof value.valueOf() === 'boolean';\n    },\n    isBoxedPrimitive(value) {\n      return ['[object Number]', '[object String]', '[object Boolean]', '[object Symbol]'].includes(Object.prototype.toString.call(value));\n    },\n    isCryptoKey(value) {\n      return typeof CryptoKey !== 'undefined' && value instanceof CryptoKey;\n    },\n    isDataView(value) {\n      return value instanceof DataView;\n    },\n    isDate(value) {\n      return value instanceof Date;\n    },\n    isExternal(value) {\n      return false; // Node.js specific\n    },\n    isFloat32Array(value) {\n      return value instanceof Float32Array;\n    },\n    isFloat64Array(value) {\n      return value instanceof Float64Array;\n    },\n    isGeneratorFunction(value) {\n      return Object.prototype.toString.call(value) === '[object GeneratorFunction]';\n    },\n    isGeneratorObject(value) {\n      return Object.prototype.toString.call(value) === '[object Generator]';\n    },\n    isInt8Array(value) {\n      return value instanceof Int8Array;\n    },\n    isInt16Array(value) {\n      return value instanceof Int16Array;\n    },\n    isInt32Array(value) {\n      return value instanceof Int32Array;\n    },\n    isKeyObject(value) {\n      return false; // Node.js specific\n    },\n    isMap(value) {\n      return value instanceof Map;\n    },\n    isMapIterator(value) {\n      return Object.prototype.toString.call(value) === '[object Map Iterator]';\n    },\n    isModuleNamespaceObject(value) {\n      return Object.prototype.toString.call(value) === '[object Module]';\n    },\n    isNativeError(value) {\n      return value instanceof Error;\n    },\n    isNumberObject(value) {\n      return typeof value === 'object' && typeof value.valueOf() === 'number';\n    },\n    isPromise(value) {\n      return value instanceof Promise;\n    },\n    isProxy(value) {\n      try {\n        Proxy.revocable(value, {});\n        return true;\n      } catch (e) {\n        return false;\n      }\n    },\n    isRegExp(value) {\n      return value instanceof RegExp;\n    },\n    isSet(value) {\n      return value instanceof Set;\n    },\n    isSetIterator(value) {\n      return Object.prototype.toString.call(value) === '[object Set Iterator]';\n    },\n    isSharedArrayBuffer(value) {\n      return value instanceof SharedArrayBuffer;\n    },\n    isStringObject(value) {\n      return typeof value === 'object' && typeof value.valueOf() === 'string';\n    },\n    isSymbolObject(value) {\n      return typeof value === 'object' && typeof value.valueOf() === 'symbol';\n    },\n    isTypedArray(value) {\n      return ArrayBuffer.isView(value) && !(value instanceof DataView);\n    },\n    isUint8Array(value) {\n      return value instanceof Uint8Array;\n    },\n    isUint8ClampedArray(value) {\n      return value instanceof Uint8ClampedArray;\n    },\n    isUint16Array(value) {\n      return value instanceof Uint16Array;\n    },\n    isUint32Array(value) {\n      return value instanceof Uint32Array;\n    },\n    isWeakMap(value) {\n      return value instanceof WeakMap;\n    },\n    isWeakSet(value) {\n      return value instanceof WeakSet;\n    },\n  }\n\n\nconst util = {\n  promisify,\n  callbackify,\n  inherits,\n  deprecate,\n  types,\n  TextEncoder,\n  TextDecoder\n};\n\nglobalThis.TextEncoder = TextEncoder;\nglobalThis.TextDecoder = TextDecoder;\n\nexport default util;\n\nexport { promisify, callbackify, inherits, deprecate, types, TextEncoder,TextDecoder };\n\n";
export default _default;
