declare const _default: "\nimport { TextEncoder, TextDecoder } from 'node:util'\n\nclass Buffer extends Uint8Array {\n  constructor(arg, encoding) {\n    if (typeof arg === 'number') {\n        super(arg);\n    } else if (typeof arg === 'string') {\n        super(Buffer._stringToBytes(arg, encoding));\n    } else if (arg instanceof ArrayBuffer) {\n        super(new Uint8Array(arg));\n    } else if (Array.isArray(arg) || arg instanceof Uint8Array) {\n        super(arg);\n    } else {\n        throw new TypeError('Invalid argument type');\n    }\n  }\n\n  static from(arg, encoding) {\n    if (typeof arg === 'string') {\n        return new Buffer(Buffer._stringToBytes(arg, encoding));\n    } else if (Array.isArray(arg) || arg instanceof Uint8Array) {\n        return new Buffer(arg);\n    } else if (arg instanceof ArrayBuffer) {\n        return new Buffer(new Uint8Array(arg));\n    } else {\n        throw new TypeError('Invalid argument type');\n    }\n  }\n\n  static alloc(size) {\n      return new Buffer(size);\n  }\n\n  static allocUnsafe(size) {\n      return new Buffer(size);\n  }\n\n  static concat(buffers, totalLength) {\n    if (!Array.isArray(buffers)) {\n        throw new TypeError('Argument must be an array of Buffers');\n    }\n    if (buffers.length === 0) {\n        return Buffer.alloc(0);\n    }\n    if (totalLength === undefined) {\n        totalLength = buffers.reduce((acc, buf) => acc + buf.length, 0);\n    }\n    const result = Buffer.allocUnsafe(totalLength);\n    let offset = 0;\n    for (const buf of buffers) {\n        result.set(buf, offset);\n        offset += buf.length;\n    }\n    return result;\n  }\n\n  toString(encoding) {\n    if (encoding === 'base64') {\n        return Buffer._bytesToBase64(this);\n    } else {\n        return Buffer._bytesToString(this, encoding);\n    }\n  }\n\n  static _stringToBytes(string, encoding) {\n    if (encoding === 'base64') {\n        return Buffer._base64ToBytes(string);\n    } else {\n        return new TextEncoder().encode(string);\n    }\n  }\n\n  static _bytesToString(bytes, encoding) {\n    if (encoding === 'utf-8' || encoding === undefined) {\n        return new TextDecoder(encoding).decode(bytes);\n    } else {\n        throw new TypeError('Unsupported encoding');\n    }\n  }\n\n  static _base64ToBytes(base64) {\n    const binaryString = atob(base64);\n    const length = binaryString.length;\n    const bytes = new Uint8Array(length);\n    for (let i = 0; i < length; i++) {\n        bytes[i] = binaryString.charCodeAt(i);\n    }\n    return bytes;\n  }\n\n  static _bytesToBase64(bytes) {\n    let binary = '';\n    for (let i = 0; i < bytes.length; i++) {\n        binary += String.fromCharCode(bytes[i]);\n    }\n    return btoa(binary);\n  }\n}\n\nglobalThis.Buffer = Buffer\n\nexport { Buffer }\n\nexport default Buffer;\n";
export default _default;
